wctrans

Function wctrans 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn wctrans(class: *const c_char) -> wctrans_t
See https://pubs.opengroup.org/onlinepubs/9799919799/functions/wctrans.html.

Safety

The caller must ensure that class is convertible to a slice reference, up to and including a terminating nul.