wctype

Function wctype 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn wctype(name: *const c_char) -> wctype_t
See https://pubs.opengroup.org/onlinepubs/9799919799/functions/wctype.html.

Safety

The caller must ensure that name is convertible to a slice reference, up to and including a terminating nul.